# coding: utf-8

# flake8: noqa

"""
    Mentortools Static Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.1.6+2522130453"

# import apis into sdk package
from static_server_connector.api.default_api import DefaultApi

# import ApiClient
from static_server_connector.api_response import ApiResponse
from static_server_connector.api_client import ApiClient
from static_server_connector.configuration import Configuration
from static_server_connector.exceptions import OpenApiException
from static_server_connector.exceptions import ApiTypeError
from static_server_connector.exceptions import ApiValueError
from static_server_connector.exceptions import ApiKeyError
from static_server_connector.exceptions import ApiAttributeError
from static_server_connector.exceptions import ApiException

# import models into sdk package
from static_server_connector.models.api_response_wrapper_boolean import ApiResponseWrapperBoolean
from static_server_connector.models.api_response_wrapper_font_upload_response import ApiResponseWrapperFontUploadResponse
from static_server_connector.models.design_switches import DesignSwitches
from static_server_connector.models.domain_migrate import DomainMigrate
from static_server_connector.models.domain_new import DomainNew
from static_server_connector.models.domain_switch import DomainSwitch
from static_server_connector.models.error import Error
from static_server_connector.models.font_upload_response import FontUploadResponse
from static_server_connector.models.page_publish import PagePublish
from static_server_connector.models.page_unpublish import PageUnpublish
from static_server_connector.models.switch_desin_request import SwitchDesinRequest
