# coding: utf-8

"""
    Mentortools Static Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from static_server_connector.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_design_get(self) -> None:
        """Test case for design_get

        """
        pass

    def test_design_post(self) -> None:
        """Test case for design_post

        """
        pass

    def test_domains_post(self) -> None:
        """Test case for domains_post

        """
        pass

    def test_file_v1_publish_post(self) -> None:
        """Test case for file_v1_publish_post

        """
        pass

    def test_file_v1_unpublish_post(self) -> None:
        """Test case for file_v1_unpublish_post

        """
        pass

    def test_fonts_v1_publish_post(self) -> None:
        """Test case for fonts_v1_publish_post

        """
        pass

    def test_root_get(self) -> None:
        """Test case for root_get

        """
        pass


if __name__ == '__main__':
    unittest.main()
